searchData={"items":[{"type":"task","title":"mix fostrom.setup","doc":"Setup Fostrom by downloading the Device Agent.\n\nThe Device Agent is automatically downloaded during initial compilation.\nHowever, if something goes wrong, you can call this task manually to download the agent.","ref":"Mix.Tasks.Fostrom.Setup.html"},{"type":"function","title":"Mix.Tasks.Fostrom.Setup.run/1","doc":"Callback implementation for  Mix.Task.run/1 .","ref":"Mix.Tasks.Fostrom.Setup.html#run/1"},{"type":"module","title":"Fostrom","doc":"[Fostrom](https://fostrom.io) is an IoT Cloud Platform built for developers. Monitor and control your fleet of devices, from microcontrollers to industrial IoT. Designed to be simple, secure, and fast. Experience first-class tooling with Device SDKs, type-safe schemas, programmable actions, and more.\n\nThe Fostrom Device SDK for Elixir works on Linux and macOS, and helps you quickly integrate, start monitoring, and controlling your IoT devices in just a few lines of code.","ref":"Fostrom.html"},{"type":"module","title":"Installation - Fostrom","doc":"The package can be installed by adding `fostrom` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:fostrom, \"~> 0.0.1\"}\n  ]\nend\n```","ref":"Fostrom.html#module-installation"},{"type":"module","title":"Configuration - Fostrom","doc":"```elixir\n# Add in config/config.exs or config/runtime.exs:\nconfig :fostrom, :config,\n  fleet_id: \" \",\n  device_id: \" \",\n  device_secret: \" \",\n  env: Config.config_env(),\n  handler: MyApp.FostromHandler\n```","ref":"Fostrom.html#module-configuration"},{"type":"module","title":"Defining a Handler - Fostrom","doc":"```elixir\ndefmodule MyApp.FostromHandler do\n  use Fostrom.Handler\n\n  # handle_mail needs to return either :ack, :reject, or :requeue\n  def handle_mail(%Fostrom.Mail{} = mail) do\n    # process the mail here\n    :ack\n  end\nend\n```","ref":"Fostrom.html#module-defining-a-handler"},{"type":"module","title":"Sending Datapoints and Messages - Fostrom","doc":"```elixir\n# To send a datapoint:\nFostrom.send_datapoint(\" \", %{ ...payload })\n\n# To send a message:\nFostrom.send_msg(\" \", %{ ...payload })\n```","ref":"Fostrom.html#module-sending-datapoints-and-messages"},{"type":"module","title":"A Note on the Fostrom Device Agent - Fostrom","doc":"The _Fostrom Device SDK_ downloads and runs the **Fostrom Device Agent** in the background. The Agent is downloaded when the library is first compiled. The Device Agent is started when your Elixir Application starts, and it remains running in the background forever.\n\nWe recommend you allow the Device Agent to run continously, even if your program has exited or crashed, so that when your program is automatically restarted by a process manager, the reconnection to Fostrom is nearly instant. However, if you wish to stop the Device Agent manually, you can call `Fostrom.DeviceAgent.stop()` in some `terminate()` callback in your application.","ref":"Fostrom.html#module-a-note-on-the-fostrom-device-agent"},{"type":"function","title":"Fostrom.send_datapoint/2","doc":"Send a Datapoint to Fostrom\n\nTakes the packet schema name and a payload. Payload must be a map, and is required to send datapoints.\n\n> #### Note {: .info}\n>\n> Ensure the packet schema exists and is for a **datapoint**.","ref":"Fostrom.html#send_datapoint/2"},{"type":"function","title":"Fostrom.send_msg/2","doc":"Send a Message to Fostrom\n\nTakes the packet schema name and a payload. Payload must either be a map or nil.\n\n> #### Note {: .info}\n>\n> Ensure the packet schema exists and is for a **message**.","ref":"Fostrom.html#send_msg/2"},{"type":"behaviour","title":"Fostrom.Handler","doc":"Define a Handler module to handle incoming mail, and other events such as `connected`, `reconnecting`, and `unauthorized`.\n\nThe easiest way to define a handler is to `use Fostrom.Handler`:\n\n```elixir\ndefmodule MyApp.FostromHandler do\n  use Fostrom.Handler\n\n  # handle_mail needs to return either :ack, :reject, or :requeue\n  def handle_mail(mail) do\n    # process the mail here\n    :ack\n  end\nend\n```\n\nNote that you need to pass the handler module in the config:\n\n```elixir\n# Add in config/config.exs or config/runtime.exs:\nconfig :fostrom, :config,\n  fleet_id: \" \",\n  device_id: \" \",\n  device_secret: \" \",\n  env: Config.config_env(),\n  handler: MyApp.FostromHandler\n```\n\nHere is a complete implementation:\n\n```elixir\ndefmodule MyApp.FostromHandler do\n  @moduledoc false\n  use Fostrom.Handler\n\n  def reconnecting(error) do\n    %{reason: reason, message: message, reconnecting_in: reconnecting_in} = error\n  end\n\n  def unauthorized(error) do\n    %{reason: reason, message: message, reconnecting_in: reconnecting_in} = error\n  end\n\n  def connected do\n    :ok\n  end\n\n  # Return :ack | :reject | :requeue from this function\n  def handle_mail(%Fostrom.Mail{} = mail) do\n    %{id: id, name: name, payload: payload, mailbox_size: mailbox_size} = mail\n    :ack\n  end\nend\n```","ref":"Fostrom.Handler.html"},{"type":"callback","title":"Fostrom.Handler.connected/0","doc":"Called when connection is established or re-established to Fostrom.","ref":"Fostrom.Handler.html#c:connected/0"},{"type":"callback","title":"Fostrom.Handler.handle_mail/1","doc":"Handle a Mail sent by Fostrom to this device.\n\nCheck out the `Fostrom.Mail` struct for the structure of the mail. You need to return either `:ack`, `:reject`, or `:requeue` from the handler. If your handler function returns anything else, or raises, or throws, `:reject` will be assumed.\n\nYou can return `:noop` from the handler, and then call the `Fostrom.Mailbox` functions to manually acknowledge the mail. Please note that the Device Mailbox is sequential, so returning `:noop` means you'll still get the same mail again if you call `Fostrom.Mailbox.next()`.","ref":"Fostrom.Handler.html#c:handle_mail/1"},{"type":"callback","title":"Fostrom.Handler.reconnecting/1","doc":"Called when connection to Fostrom is lost, and the Device Agent is going to retry connecting after sometime.","ref":"Fostrom.Handler.html#c:reconnecting/1"},{"type":"callback","title":"Fostrom.Handler.unauthorized/1","doc":"Called when the device is not authorized to connect to Fostrom. This could be if the device is disabled, the secret is incorrect, or the device does not exist.","ref":"Fostrom.Handler.html#c:unauthorized/1"},{"type":"module","title":"Fostrom.Mail","doc":"`%Fostrom.Mail{}` is the struct delivered to your handler, and is returned from `Fostrom.Mailbox.next/0` if the mailbox is not empty.","ref":"Fostrom.Mail.html"},{"type":"type","title":"Fostrom.Mail.t/0","doc":"* `id`: u64 integer\n* `name`: name of the packet schema\n* `payload`: a map (with string keys)\n* `mailbox_size`: u16 integer","ref":"Fostrom.Mail.html#t:t/0"},{"type":"module","title":"Fostrom.Mailbox","doc":"`Fostrom.Mailbox` provides manual access to the Device Mailbox.\n\nUsually you'll just implement the `Fostrom.Handler` behaviour in your application code,\nand handle incoming mail there. However, if you prefer to handle it manually, you can do so\nusing this module.","ref":"Fostrom.Mailbox.html"},{"type":"function","title":"Fostrom.Mailbox.ack/1","doc":"Acknowledge the Mail.\n\nYou would usually acknowledge when you want to signify that the mail was successfully processed by the device.","ref":"Fostrom.Mailbox.html#ack/1"},{"type":"function","title":"Fostrom.Mailbox.next/0","doc":"Fetch the next available mail from the mailbox.","ref":"Fostrom.Mailbox.html#next/0"},{"type":"function","title":"Fostrom.Mailbox.reject/1","doc":"Reject the Mail.\n\nYou would usually reject when you want to signify that the mail was not successfully processed by the device.","ref":"Fostrom.Mailbox.html#reject/1"},{"type":"function","title":"Fostrom.Mailbox.requeue/1","doc":"Requeue the Mail.\n\nRequeueing moves the mail to the end of the queue and allows you to process the next mail.","ref":"Fostrom.Mailbox.html#requeue/1"},{"type":"function","title":"Fostrom.Mailbox.status/0","doc":"Fetch the mailbox size and the next mail's ID and name.","ref":"Fostrom.Mailbox.html#status/0"},{"type":"module","title":"Fostrom.Mailbox.Status","doc":"Return value of `Fostrom.Mailbox.status/0`.\n\nThis struct is only returned when there is mail in the mailbox. Otherwise `Fostrom.Mailbox.status/0` returns `{:ok, :mailbox_empty}`.","ref":"Fostrom.Mailbox.Status.html"},{"type":"type","title":"Fostrom.Mailbox.Status.t/0","doc":"* `mailbox_size`: u16 integer\n* `next_mail_id`: u64 integer\n* `next_mail_name`: name of the packet schema","ref":"Fostrom.Mailbox.Status.html#t:t/0"},{"type":"module","title":"Fostrom.DeviceAgent","doc":"Manages the starting and stopping of the Fostrom Device Agent","ref":"Fostrom.DeviceAgent.html"},{"type":"function","title":"Fostrom.DeviceAgent.stop/0","doc":"Stop the Fostrom Device Agent","ref":"Fostrom.DeviceAgent.html#stop/0"},{"type":"exception","title":"Fostrom.Exception","doc":"A `Fostrom.Exception` contains a reason and a message. It also contains `reconnecting_in` (in milliseconds) when the reconnecting or unauthorized callbacks are called.","ref":"Fostrom.Exception.html"},{"type":"type","title":"Fostrom.Exception.t/0","doc":"","ref":"Fostrom.Exception.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}